# -*- coding: utf-8 -*-
import click

from .main import  run_on_cif
from .settings import CHARGE_DATA_PATH, IONIZATION_DATA_PATH

@click.command("cli")
@click.argument(
    "cif",
    type=click.Path(exists=True),
    required=True,
    # help="Path to CIF containing the crystal structure.",
)
@click.option(
    "--output_type",
    "-ot",
    type=click.Choice(["list", "cif"], case_sensitive=False),
    default="cif",
)
@click.option(
    "--dielectric_screening",
    "-ds",
    type=float,
    default=1.2,
    help="The dielectric screening parameter. Corresponds to eps_eff = 1.67",
)
@click.option(
    "--h_electron_affinity",
    "-hea",
    type=float,
    default=-2.0,
    help="The electron affinity of hydrogen.",
)
@click.option(
    "--charge_precision",
    "-cp",
    type=int,
    default=3,
    help="Number of digits to use for point charges.",
)
@click.option(
    "--method",
    "-met",
    type=click.Choice(["ewald", "nonperiodic"], case_sensitive=False),
    default="ewald",
    help=" Method to compute the Coulombic interaction",
)
@click.option(
    "--num_cells_real",
    "-nr",
    type=int,
    default=2,
    help="Number of 'expansion' unit cells to consider in periodic calculation ('real space'). 2 corresponds to 5x5x5",
)
@click.option(
    "--num_cells_freq",
    "-nf",
    type=int,
    default=2,
    help="Number of 'expansion' unit cells to consider in periodic calculation ('frequency space'). 2 corresponds to 5x5x5",
)
@click.option(
    "--ewald_splitting",
    "-es",
    type=float,
    default=50,
    help=" Method to compute the Coulombic interaction",
)
@click.option(
    "--ionization_data_path",
    "-id",
    type=click.Path(exists=True),
    default=IONIZATION_DATA_PATH,
    help="File with ionization potentials and electron affinities.",
)
@click.option(
    "--charge_data_path",
    "-cd",
    type=click.Path(exists=True),
    default=CHARGE_DATA_PATH,
    help="File with common oxidation states.",
)
@click.option(
    "--outpath",
    "-o",
    type=click.Path(),
    default=None,
)
def cli(
    cif,
    output_type,
    dielectric_screening,
    h_electron_affinity,
    charge_precision,
    method,
    num_cells_real,
    num_cells_freq,
    ewald_splitting,
    ionization_data_path,
    charge_data_path,
    outpath,
):
    result = run_on_cif(
        cif,
        output_type,
        dielectric_screening,
        h_electron_affinity,
        charge_precision,
        method,
        num_cells_real,
        num_cells_freq,
        ewald_splitting,
        ionization_data_path,
        charge_data_path,
        outpath,
    )

    if outpath is None:
        print(result)



# -*- coding: utf-8 -*-
import json
import pathlib
from typing import Union

import pyeqeq_eqeq

from .settings import CHARGE_DATA_PATH, IONIZATION_DATA_PATH


def run_on_cif(
    cif,
    output_type: str = "list",
    dielectric_screening: float = 1.2,
    h_electron_affinity: float = -2.0,
    charge_precision: int = 3,
    method: str = "ewald",
    num_cells_real: int = 2,
    num_cells_freq: int = 2,
    ewald_splitting: float = 50,
    ionization_data_path: Union[str, pathlib.Path] = IONIZATION_DATA_PATH,
    charge_data_path: Union[str, pathlib.Path] = CHARGE_DATA_PATH,
    outpath: Union[str, pathlib.Path] = None,
):
    output_type = output_type.lower()
    method = method.lower()
    result = pyeqeq_eqeq.run(
        cif,
        "json" if output_type == "list" else output_type,
        dielectric_screening,
        h_electron_affinity,
        charge_precision,
        method,
        num_cells_real,
        num_cells_freq,
        ewald_splitting,
        ionization_data_path,
        charge_data_path,
    )
    if outpath is not None:
        with open(outpath, "w") as handle:
            handle.write(result)

    if output_type == "list":
        return json.loads(result)
    return result




import pkg_resources

IONIZATION_DATA_PATH = pkg_resources.resource_filename(
    "pyeqeq", "data/ionizationdata.dat"
)
CHARGE_DATA_PATH = pkg_resources.resource_filename("pyeqeq", "data/chargecenters.dat")



# -*- coding: utf-8 -*-
# Copyright 2020 PyePAL authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Model agnostic Python implementation of the epsilon-PAL algorithm"""

from distutils.core import setup
from pybind11.setup_helpers import Pybind11Extension, build_ext


eqeq_module = Pybind11Extension(
    "pyeqeq_eqeq", ["src/main.cpp"], include_dirs=["src"], extra_compile_args=["-O3"]
)


setup(
    ext_modules=[eqeq_module],
    cmdclass={"build_ext": build_ext},
    package_data={"": ["data/*.dat"]},
    include_package_data=True,
    headers=['src/main.h']
)
